@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _OPEN_LOG_MODE_FACTORY_H_
-#define _OPEN_LOG_MODE_FACTORY_H_
+#ifndef LOG_MODE_OPEN_FACTORY_H
+#define LOG_MODE_OPEN_FACTORY_H
 
 #include "logModeFactory.h"
 #include "logModeConfiguration.h"
@@ -34,12 +34,12 @@ public:
 
     ~OpenLogModeFactory();
 
-    QList<LogMode *> createLogModes() const Q_DECL_OVERRIDE;
+    QList<LogMode *> createLogModes() const override;
 
-    LogModeAction *createLogModeAction() const Q_DECL_OVERRIDE;
+    LogModeAction *createLogModeAction() const override;
 
 private:
     QWidget *parent;
 };
 
-#endif // _OPEN_LOG_MODE_FACTORY_H_
+#endif // _LOG_MODE_OPEN_FACTORY_H
