@@ -26,7 +26,7 @@
 #include <QCheckBox>
 
 #include <KLocalizedString>
-#include <kurlrequester.h>
+#include <KUrlRequester>
 
 #include "globals.h"
 #include "logging.h"
