@@ -51,7 +51,7 @@ private:
 
 void KioLogFileReaderTest::initTestCase()
 {
-    logDebug() << "Hello" << endl;
+    logDebug() << "Hello";
 }
 
 void KioLogFileReaderTest::testKioLogFileReader()
@@ -63,7 +63,7 @@ void KioLogFileReaderTest::testKioLogFileReader()
     KioLogFileReader *logFileReader = new KioLogFileReader(logFile);
     logFileReader->open();
 
-    connect(logFileReader, &KioLogFileReader::lineRead, this, [=](const QString &line) { logDebug() << "Line " << line << endl; static QFile file(fixturePath); static bool open = false; if (!open) { QVERIFY(file.open(QIODevice::ReadOnly | QIODevice::Text)); open = true; } static QTextStream stream(&file); QCOMPARE(line, stream.readLine());
+    connect(logFileReader, &KioLogFileReader::lineRead, this, [=](const QString &line) { logDebug() << "Line " << line; static QFile file(fixturePath); static bool open = false; if (!open) { QVERIFY(file.open(QIODevice::ReadOnly | QIODevice::Text)); open = true; } static QTextStream stream(&file); QCOMPARE(line, stream.readLine());
     });
 }
 
